@@ -1,9 +1,4 @@
-# encoding: binary
-
-require File.expand_path('../../../spec_helper', __FILE__)
-
-
-describe AMQ::Protocol::Method, ".encode_body" do
+RSpec.describe AMQ::Protocol::Method, ".encode_body" do
   it "encodes 1-byte long payload as exactly 1 body frame" do
     expect(described_class.encode_body('1', 1, 65536).size).to eq(1)
   end
